@@ -87,9 +87,7 @@ class LoadBalancer:
         self.host = host
         self.port = port
         self._balancer = ResourceBalancer()
-        self._timer = Timer(self.REFRESH_INTERVAL, self.refresh)
         self.refresh()
-        self._timer.start()
 
     def acquire_addr(self):
         return self._balancer.acquire()
@@ -101,6 +99,7 @@ class LoadBalancer:
             self._balancer.provision(hosts)
         except:
             exception("Failed to refresh endpoints for %s:%d", self.host, self.port)
+        Timer(self.REFRESH_INTERVAL, self.refresh).start()
 
 
 if __name__ == "__main__":
